summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqaction.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqaction.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqaction.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqaction.cpp b/tqtinterface/qt4/src/widgets/tqaction.cpp
index 8ffa773..8a65d06 100644
--- a/tqtinterface/qt4/src/widgets/tqaction.cpp
+++ b/tqtinterface/qt4/src/widgets/tqaction.cpp
@@ -210,7 +210,7 @@ TQActionPrivate::~TQActionPrivate()
while ( ( mi = itmi.current() ) ) {
++itmi;
TQPopupMenu* menu = mi->popup;
- if ( menu->tqfindItem( mi->id ) )
+ if ( menu->findItem( mi->id ) )
menu->removeItem( mi->id );
}
@@ -356,7 +356,7 @@ TQString TQActionPrivate::menuText() const
{
if ( menutext.isNull() ) {
TQString t(text);
- t.tqreplace('&', "&&");
+ t.replace('&', "&&");
return t;
}
return menutext;
@@ -1105,7 +1105,7 @@ void TQAction::addedTo( int index, TQPopupMenu *menu )
void TQAction::showtqStatusText( const TQString& text )
{
#ifndef TQT_NO_STATUSBAR
// tqfind out whether we are clearing the status bar by the popup that actually set the text
static TQPopupMenu *lastmenu = 0;
TQObject *s = (TQObject*)sender();
if ( s ) {
@@ -1363,7 +1363,7 @@ void TQActionGroupPrivate::update( const TQActionGroup* that )
continue;
int index;
- tqparent->tqfindPopup( popup, &index );
+ tqparent->findPopup( popup, &index );
int id = tqparent->idAt( index );
if ( !that->iconSet().isNull() )
tqparent->changeItem( id, that->iconSet(), that->menuText() );
@@ -1578,7 +1578,7 @@ bool TQActionGroup::usesDropDown() const
*/
void TQActionGroup::add( TQAction* action )
{
- if ( d->actions.tqcontainsRef( action ) )
+ if ( d->actions.containsRef( action ) )
return;
d->actions.append( action );
@@ -1769,14 +1769,14 @@ bool TQActionGroup::addTo( TQWidget* w )
popup = (TQPopupMenu*)w;
}
for ( TQPtrListIterator<TQAction> it( d->actions); it.current(); ++it ) {
// #### do an addedTo( index, popup, action), need to tqfind out index
it.current()->addTo( popup );
}
return TRUE;
}
for ( TQPtrListIterator<TQAction> it( d->actions); it.current(); ++it ) {
// #### do an addedTo( index, popup, action), need to tqfind out index
it.current()->addTo( w );
}
@@ -2051,7 +2051,7 @@ void TQActionGroup::internalComboBoxHighlighted( int index )
*/
void TQActionGroup::internalToggle( TQAction *a )
{
- int index = d->actions.tqfind( a );
+ int index = d->actions.find( a );
if ( index == -1 )
return;
@@ -1105,7 +1105,7 @@ void TQAction::addedTo( int index, TQPopupMenu *menu )
{
#ifndef TQT_NO_STATUSBAR
- // tqfind out whether we are clearing the status bar by the popup that actually set the text
+ // find out whether we are clearing the status bar by the popup that actually set the text
static TQPopupMenu *lastmenu = 0;
TQObject *s = (TQObject*)sender();
@@ -1769,14 +1769,14 @@ bool TQActionGroup::addTo( TQWidget* w )
}
for ( TQPtrListIterator<TQAction> it( d->actions); it.current(); ++it ) {
- // #### do an addedTo( index, popup, action), need to tqfind out index
+ // #### do an addedTo( index, popup, action), need to find out index
it.current()->addTo( popup );
}
@@ -1769,14 +1769,14 @@ bool TQActionGroup::addTo( TQWidget* w )
}
for ( TQPtrListIterator<TQAction> it( d->actions); it.current(); ++it ) {
- // #### do an addedTo( index, popup, action), need to tqfind out index
+ // #### do an addedTo( index, popup, action), need to find out index
it.current()->addTo( w );
}